# Changelog

This page lists the key changes made between consecutive versions of PySLSQP.
A more detailed description of major changes between releases can be found
in `RELEASE_NOTES.md` in the project root directory.

***********************************
## Version 0.1.0 (June 1, 2024)

- Initial release of PySLSQP